@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3643 $
+//  $Revision: 4156 $
 //
-//  $LastChangedDate: 2011-12-21 15:00:32 -0800 (Wed, 21 Dec 2011) $
+//  $LastChangedDate: 2012-04-10 10:13:18 -0700 (Tue, 10 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -55,10 +55,12 @@
 #include <Base/cmtkImageOperationConnectedComponents.h>
 #include <Base/cmtkImageOperationDownsample.h>
 #include <Base/cmtkImageOperationHistogramEqualization.h>
+#include <Base/cmtkImageOperationHoughTransformSphere.h>
 #include <Base/cmtkImageOperationCropRegion.h>
 #include <Base/cmtkImageOperationCropThreshold.h>
 #include <Base/cmtkImageOperationScaleToRange.h>
 #include <Base/cmtkImageOperationThreshold.h>
+#include <Base/cmtkImageOperationOtsuThreshold.h>
 #include <Base/cmtkImageOperationPruneHistogram.h>
 #include <Base/cmtkImageOperationSetPadding.h>
 #include <Base/cmtkImageOperationMapValues.h>
@@ -66,6 +68,7 @@
 #include <Base/cmtkImageOperationRegionFilter.h>
 #include <Base/cmtkImageOperationMedialSkeleton.h>
 #include <Base/cmtkImageOperationGaussFilter.h>
+#include <Base/cmtkImageOperationLaplaceFilter.h>
 #include <Base/cmtkImageOperationDistanceMap.h>
 #include <Base/cmtkImageOperationRevert.h>
 
@@ -146,6 +149,10 @@ doMain( const int argc, const char* argv[] )
     cl.AddCallback( Key( "thresh-below-to-padding" ), &cmtk::ImageOperationThreshold::NewBelowToPadding, "Set all values below threshold to padding value." );
     cl.AddCallback( Key( "thresh-above-to-padding" ), &cmtk::ImageOperationThreshold::NewAboveToPadding, "Set all values above threshold to padding value." );
     cl.AddCallback( Key( "binarize-thresh" ), &cmtk::ImageOperationThreshold::NewBinarize, "Set all values below threshold to 0, all values equal or above to 1." );
+    cl.AddCallback( Key( "otsu-thresh" ), &cmtk::ImageOperationOtsuThreshold::New, "Binarize image to 0/1 using threshold computed with Otsu's method. "
+		    "Argument is number of histogram bins for threshold computation." );
+    cl.AddCallback( Key( "otsu-thresh-nbins" ), &cmtk::ImageOperationOtsuThreshold::NewBins, "Binarization using Otsu's method with user-defined number of histogram bins "
+		    "for threshold computation." );
     cl.AddCallback( Key( "prune-histogram" ), &cmtk::ImageOperationPruneHistogram::New, "Threshold image by 'intensity histogram pruning', i.e., for given argument n [histogram bins] "
 		    "determine thresholds such that the 1/n-th fraction of highest and lowest voxels are thresholded." );
     cl.AddCallback( Key( "prune-histogram-high" ), &cmtk::ImageOperationPruneHistogram::NewHigh, "Like '--prune-histograms', but only remove high intensities." );
@@ -198,8 +205,14 @@ doMain( const int argc, const char* argv[] )
 		    "Filter image with Gaussian kernel. This operation takes a single real-valued parameter, which specifies the kernel coefficient sigma in world units [e.g., mm] as the parameter." );
     cl.AddCallback( Key( "gaussian-filter-fwhm" ), &cmtk::ImageOperationGaussFilter::NewFWHM, 
 		    "Filter image with Gaussian kernel. This operation takes a single real-valued parameter, which specifies the kernel full width at half maximum in world units [e.g., mm]." );
+    cl.AddCallback( Key( "laplace-filter" ), &cmtk::ImageOperationLaplaceFilter::New, "Filter image with edge-enhancing Laplacian kernel." );
     cl.EndGroup();
-
+    
+    cl.BeginGroup( "Feature", "Feature Detection Operations" );
+    cl.AddCallback( Key( "hough-sphere" ), &cmtk::ImageOperationHoughTransformSphere::New, "Hough transform to detect sphere with a given radius. "
+		    "The radius in world units (typically mm) is provided as an argument to this operation." );
+    cl.EndGroup();
+    
     cl.BeginGroup( "Grid", "Grid Operations" );
     cl.AddCallback( Key( "downsample-select" ), &cmtk::ImageOperationDownsample::NewSelect, "Downsample image by pixel selection using per-axis factors 'Fx,Fy,Fz' or using single factor 'Fxyz'" );
     cl.AddCallback( Key( "downsample-average" ), &cmtk::ImageOperationDownsample::NewAverage, "Downsample image by averaging using per-axis factors 'Fx,Fy,Fz' or using single factor 'Fxyz'" );
