@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3647 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2011-12-22 10:49:31 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,7 +41,7 @@
 #include <Base/cmtkMatrix4x4.h>
 
 #include <IO/cmtkStudyList.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkClassStreamAffineXform.h>
 #include <IO/cmtkClassStreamStudyList.h>
 
@@ -164,7 +164,7 @@ doMain( const int argc, const char* argv[] )
     float center[3];
     if ( 3 == sscanf( CenterStr, "%f,%f,%f", center+0, center+1, center+2 ) )
       {
-      xform->ChangeCenter( cmtk::FixedVector<3,cmtk::Types::Coordinate>( center ) );
+      xform->ChangeCenter( cmtk::FixedVector<3,cmtk::Types::Coordinate>::FromPointer( center ) );
       }
     }
   
@@ -173,7 +173,7 @@ doMain( const int argc, const char* argv[] )
     float offset[3];
     if ( 3 == sscanf( OffsetStr, "%f,%f,%f", offset+0, offset+1, offset+2 ) )
       {
-      xform->Translate( xform->RotateScaleShear( cmtk::FixedVector<3,cmtk::Types::Coordinate>( offset ) ) );
+      xform->Translate( xform->RotateScaleShear( cmtk::FixedVector<3,cmtk::Types::Coordinate>::FromPointer( offset ) ) );
       }
     }
 
@@ -182,7 +182,7 @@ doMain( const int argc, const char* argv[] )
     float xlate[3];
     if ( 3 == sscanf( TranslateStr, "%f,%f,%f", xlate+0, xlate+1, xlate+2 ) )
       {
-      xform->Translate( cmtk::FixedVector<3,cmtk::Types::Coordinate>( xlate ) );
+      xform->Translate( cmtk::FixedVector<3,cmtk::Types::Coordinate>::FromPointer( xlate ) );
       }
     }
   
@@ -190,7 +190,7 @@ doMain( const int argc, const char* argv[] )
     {
     if ( AppendToOutput )
       {
-      cmtk::ClassStream outStream( OutList, cmtk::ClassStream::MODE_APPEND );
+      cmtk::ClassStreamOutput outStream( OutList, cmtk::ClassStreamOutput::MODE_APPEND );
       if ( Inverse )
 	outStream << *xform->GetInverse();
       else
