@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4431 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-06-13 11:17:08 -0700 (Wed, 13 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -360,8 +360,7 @@ WriteAligned
       {
       for ( int x = 0; x < originalVolume->GetDims()[0]; ++x, ++offset ) 
 	{
-	cmtk::UniformVolume::CoordinateVectorType v = originalVolume->GetGridLocation( x, y, z );
-	alignment->ApplyInPlace( v );
+	const cmtk::UniformVolume::CoordinateVectorType v = alignment->Apply( originalVolume->GetGridLocation( x, y, z ) );
 
 	if ( interpolator->GetDataAt( v, data ) )
 	  {
