@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4381 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -236,16 +236,16 @@ doMain ( const int argc, const char* argv[] )
       if ( xform )
 	{
 	if ( InvertXform )
-	  success = success && xform->ApplyInverseInPlace( v1 );
+	  success = success && xform->ApplyInverse( v1, v1 );
 	else
-	  xform->ApplyInPlace( v1 );
+	  v1 = xform->Apply( v1 );
 	}
       if ( minusXform )
 	{
 	if ( InvertMinusXform )
-	  success = success && minusXform->ApplyInverseInPlace( v0 );
+	  success = success && minusXform->ApplyInverse( v0, v0 );
 	else
-	  minusXform->ApplyInPlace( v0 );
+	  v0 = minusXform->Apply( v0 );
 	}
 
       if ( success )
@@ -277,16 +277,16 @@ doMain ( const int argc, const char* argv[] )
       if ( xform )
 	{
 	if ( InvertXform )
-	  success = success && xform->ApplyInverseInPlace( v1 );
+	  success = success && xform->ApplyInverse( v1, v1 );
 	else
-	  xform->ApplyInPlace( v1 );
+	  v1 = xform->Apply( v1 );
 	}
       if ( minusXform )
 	{
 	if ( InvertMinusXform )
-	  success = success && minusXform->ApplyInverseInPlace( v0 );
+	  success = success && minusXform->ApplyInverse( v0, v0 );
 	else
-	  minusXform->ApplyInPlace( v0 );
+	  v0 = minusXform->Apply( v0 );
 	}
 
       if ( success )
