@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4398 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-05-31 11:48:23 -0700 (Thu, 31 May 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -58,7 +58,7 @@ cmtk
  * the matrix itself or a parameter vector. Both representations are 
  * permanently accessible and held mutually up-to-date whenever one of them
  * changes.
- *\author $Author: torsten_at_home $
+ *\author $Author: torstenrohlfing $
  */
 class AffineXform : 
   /// Inherit virtual interface from generic transformation.
@@ -182,11 +182,6 @@ public:
   /// Clone inverse of this transformation.
   virtual Self* MakeInverse () const;
 
-  /** Compute difference to another affine transformation.
-   *\todo It is probably not a good idea to return a dynamically allocated object here.
-   */
-  virtual Self::SmartPtr GetDifference( const AffineXform& other ) const;
-
   /// Get linked inverse of this transformation.
   Self::SmartPtr& GetInverse();
 
@@ -246,18 +241,10 @@ public:
   /// Apply transformation to vector.
   virtual Self::SpaceVectorType Apply ( const Self::SpaceVectorType& vec ) const 
   {
-    Self::SpaceVectorType Result( vec );
-    this->ApplyInPlace( Result );
-    return Result;
+    return vec * this->Matrix;
   }
   
-  /// Apply transformation to existing vector.
-  void ApplyInPlace( Self::SpaceVectorType& vec ) const 
-  {
-    vec *= this->Matrix;
-  }
-
-  /** Return origin of warped vector.
+  /** Apply inverse of this transformation to vector.
    */
   virtual bool ApplyInverse ( const Self::SpaceVectorType& v, Self::SpaceVectorType& u, const Types::Coordinate = 0.01  ) const
   {
@@ -265,14 +252,6 @@ public:
     return true;
   }
 
-  /** Return origin of warped vector.
-   */
-  virtual bool ApplyInverseInPlace( Self::SpaceVectorType& v, const Types::Coordinate = 0.01  ) const
-  {
-    this->GetInverse()->ApplyInPlace( v );
-    return true;
-  }
-
   /**\name Read-only parameter retrieval.
    */
   //@{
