@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4562 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2012-10-23 11:29:15 -0700 (Tue, 23 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -607,7 +607,7 @@ DataGrid
       for ( int x = 0; x < this->m_Dims[0]; ++x, ++ofs )
 	{
 	Types::DataItem value;
-	if ( this->GetDataAt( value, x, y, z ) )
+	if ( this->GetDataAt( value, x, y, z ) && MathUtil::IsFinite( value ) )
 	  {
 	  const Types::Coordinate pixelCOM[3] = { value * x, value * y, value * z };
 	  com += Self::SpaceVectorType::FromPointer( pixelCOM );
@@ -634,7 +634,7 @@ DataGrid
       for ( int x = 0; x < this->m_Dims[0]; ++x, ++ofs )
 	{
 	Types::DataItem value;
-	if ( this->GetDataAt( value, x, y, z ) )
+	if ( this->GetDataAt( value, x, y, z ) && MathUtil::IsFinite( value ) )
 	  {
 	  const Types::Coordinate pixelMoment[3] = { value * fabs(x - com[0]), value * fabs(y - com[1]), value * fabs(z - com[2]) };
 	  firstOrderMoment += Self::SpaceVectorType::FromPointer( pixelMoment );
