@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4326 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-05-08 12:05:35 -0700 (Tue, 08 May 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -85,8 +85,8 @@ public:
   {
     for ( std::list<LandmarkPair>::iterator it = this->m_LandmarkPairs.begin(); it != this->m_LandmarkPairs.end(); ++it )
       {
-      xform.ApplyInPlace( it->m_Location );
-      xform.ApplyInPlace( it->m_TargetLocation );
+      it->m_Location = xform.Apply( it->m_Location );
+      it->m_TargetLocation = xform.Apply( it->m_TargetLocation );
       }
   }
 
