@@ -2,7 +2,7 @@
 //
 //  Copyright 2010 Torsten Rohlfing
 //
-//  Copyright 2011 SRI International
+//  Copyright 2011, 2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3646 $
+//  $Revision: 4375 $
 //
-//  $LastChangedDate: 2011-12-22 10:10:55 -0800 (Thu, 22 Dec 2011) $
+//  $LastChangedDate: 2012-05-30 13:01:18 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -32,6 +32,8 @@
 
 #include "cmtkImageOperationMapValues.h"
 
+#include <limits>
+
 cmtk::ImageOperationMapValues::ImageOperationMapValues( const char* mapping, const bool exclusive )
   : m_Exclusive( exclusive )
 {
@@ -70,7 +72,7 @@ cmtk::ImageOperationMapValues::ImageOperationMapValues( const char* mapping, con
 	
 	for ( size_t i = 0; i < fromValues.size(); ++i )
 	  {
-	  this->m_Mapping[fromValues[i]] = MathUtil::GetDoubleNaN();
+	  this->m_Mapping[fromValues[i]] = std::numeric_limits<double>::signaling_NaN();
 	  }
 	}
       else
