@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -950,7 +950,7 @@ SplineWarpXform::GetInverseConsistencyError
 	{
 	if ( inverse->InDomain( *pVec ) ) 
 	  {
-	  inverse->ApplyInPlace( *pVec );
+	  *pVec = inverse->Apply( *pVec );
 	  v = volume->GetGridLocation( x, y, z );
 	  v -= *pVec;
 	  result += v.RootSumOfSquares();
