@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4415 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-06-04 14:57:12 -0700 (Mon, 04 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -196,16 +196,6 @@ public:
    */
   virtual bool ApplyInverse ( const Self::SpaceVectorType& v, Self::SpaceVectorType& u, const Types::Coordinate accuracy = 0.01  ) const;
 
-  /** Return origin of warped vector.
-   * Note that since this class of transformation is not closed under inversion
-   * this function computes only a more or less accurate numerical 
-   * approximation to the actual origin of a warped vector. Note also that this
-   * computation is everything but computationally efficient.
-   *\return True is the given inverse was succesfully comuted, false if the
-   * given warped vector was outside the target domain of this transformation.
-   */
-  virtual bool ApplyInverseInPlace( Self::SpaceVectorType& v, const Types::Coordinate accuracy = 0.01  ) const;
-
   /** Return origin of warped vector.
    * Note that since this class of transformation is not closed under inversion
    * this function computes only a more or less accurate numerical 
@@ -220,11 +210,12 @@ public:
    *\return True is the given inverse was succesfully comuted, false if the
    * given warped vector was outside the target domain of this transformation.
    */
-  virtual bool ApplyInverseInPlaceWithInitial( Self::SpaceVectorType& v, const Self::SpaceVectorType& initial, const Types::Coordinate accuracy = 0.01 ) const;
+  virtual bool ApplyInverseWithInitial( const Self::SpaceVectorType& v, Self::SpaceVectorType& u, const Self::SpaceVectorType& initial, const Types::Coordinate accuracy = 0.01 ) const;
 
   /// Replace existing vector with transformed location.
-  virtual void ApplyInPlace( Self::SpaceVectorType& v ) const 
+  virtual Self::SpaceVectorType Apply( const Self::SpaceVectorType& v ) const 
   {
+    Self::SpaceVectorType vTransformed;
     Types::Coordinate f[3];
     int grid[3];
     
@@ -271,9 +262,11 @@ public:
 	mm += CubicSpline::ApproxSpline( m, f[2] ) * ll;
 	coeff_mm += nextK;
 	}
-      v[dim] = mm;
+      vTransformed[dim] = mm;
       ++coeff;
       }
+  
+    return vTransformed;
   }
   
   /// Precompute spline parameters for one point.
