@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -802,8 +802,7 @@ SplineWarpXform::RelaxToUnfold()
 	    {
 	    Self::SpaceVectorType cp = Self::SpaceVectorType::FromPointer( &(pureDeformation[0])+param );
 	    cp += this->GetOriginalControlPointPosition( i, j, k );
-	    
-	    this->m_InitialAffineXform->ApplyInPlace( cp );
+	    cp = this->m_InitialAffineXform->Apply( cp );
 	    
 	    for ( int dim = 0; dim < 3; ++dim )
 	      this->m_Parameters[param+dim] = cp[dim];
