@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4236 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-04-20 14:55:02 -0700 (Fri, 20 Apr 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -96,14 +96,10 @@ public:
   /// Destructor.
   virtual ~UniformVolume() {}
 
-  /** Resample other volume to given resolution.
-   *\param other Original volume that will be resampled.
-   *\param resolution Resolution of the newly created volume in world units.
-   *\param allowUpsampling If true, then local upsampling is allowed in regions
-   * where the original image resolution (non-uniform) was coarser than the
-   * given resolution of the resampled volume.
+  /** Copy constructor.
+   *\param other Original volume that will be copied.
    */
-  UniformVolume( const UniformVolume& other, const Types::Coordinate resolution = 0, const bool allowUpsampling = false );
+  UniformVolume( const UniformVolume& other );
 
   /** Create uniform volume "from scratch".
    *\param dims Number of grid elements for the three spatial dimensions.
@@ -127,6 +123,15 @@ public:
     return Superclass::GridMatches( other ) && ((this->m_Delta-other.m_Delta).MaxAbsValue() < 1e-5) && ((this->m_Offset-other.m_Offset).MaxAbsValue() < 1e-5);
   }
 
+  /** Resample volume to given resolution.
+   *\param resolution Resolution of the newly created volume in world units.
+   *\param allowUpsampling If true, then local upsampling is allowed in regions
+   * where the original image resolution (non-uniform) was coarser than the
+   * given resolution of the resampled volume.
+   *\return Newly created, resampled volume.
+   */
+  virtual UniformVolume* GetResampled( const Types::Coordinate resolution, const bool allowUpsampling = false ) const;
+
   /** Coordinate transformation from index to physical position.
    * This incorporates image axis directions and first pixel offset.
    *\note Strictly, this is not a transformation from the pixel index
@@ -135,7 +140,7 @@ public:
    *  space back into physical space.
    */
   AffineXform::MatrixType m_IndexToPhysicalMatrix;
-
+  
   /** Change volume coordinate space.
    * Re-arrange volume's direction vectors to refer to a different coordinate space.
    *\invariant This should keep the result of GetOrientationFromDirections invariant.
@@ -434,7 +439,7 @@ public:
   virtual const Self::CoordinateVectorType GetGridLocation( const int x, const int y, const int z ) const 
   {
     const Types::Coordinate loc[3] = { this->m_Offset[0] + x * this->m_Delta[0], this->m_Offset[1] + y * this->m_Delta[1], this->m_Offset[2] + z * this->m_Delta[2] };
-    return Self::CoordinateVectorType( loc );
+    return Self::CoordinateVectorType::FromPointer( loc );
   }
   
   /** Get a grid location in image coordinates.
@@ -475,7 +480,7 @@ public:
     const Types::Coordinate loc[3] = { this->m_Offset[0] +  (idx % this->nextJ) * this->m_Delta[0], 
 				       this->m_Offset[1] +  (idx % this->nextK) / this->nextJ * this->m_Delta[1], 
 				       this->m_Offset[2] +  (idx / this->nextK) * this->m_Delta[2] };
-    return Self::CoordinateVectorType( loc );
+    return Self::CoordinateVectorType::FromPointer( loc );
   }
 
   //@}
@@ -512,15 +517,6 @@ public:
    */
   Self::SmartPtr GetCroppedVolume( const Self::RegionType& region ) const;
 
-  /** Return projection (e.g., MIP, sum) along one axis.
-   * This function calls its equivalent in DataGrid and adds calibration
-   * info (i.e., correct pixel sizes) to the resulting image.
-   *\note The pixel size if taken from the size of the first grid element along
-   * each axis -- non-uniform spacings will lead to incorrect results.
-   */
-  template<class TAccumulator>
-  ScalarImage* ComputeProjection( const int axis ) const;
-  
   /// Get center of mass of pixel data.
   virtual Self::CoordinateVectorType GetCenterOfMass() const
   {
