@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -88,19 +88,13 @@ WarpXform::GetDerivativeLandmarksMSD
   this->m_Parameters[idx] += step;
   for ( LandmarkPairList::const_iterator it = ll.begin(); it != ll.end(); ++it )
     {
-    Self::SpaceVectorType source = it->m_Location;
-    Self::SpaceVectorType target = it->m_TargetLocation;
-    this->ApplyInPlace( source );
-    upperMSD += (source - target).SumOfSquares();
+    upperMSD += (this->Apply( it->m_Location ) - it->m_TargetLocation).SumOfSquares();
     }
   
   this->m_Parameters[idx] = pOld - step;
   for ( LandmarkPairList::const_iterator it = ll.begin(); it != ll.end(); ++it )
     {
-    Self::SpaceVectorType source = it->m_Location;
-    Self::SpaceVectorType target = it->m_TargetLocation;
-    this->ApplyInPlace( source );
-    lowerMSD += (source - target).SumOfSquares();
+    lowerMSD += (this->Apply( it->m_Location ) - it->m_TargetLocation).SumOfSquares();
     }
   this->m_Parameters[idx] = pOld;
   
@@ -132,12 +126,10 @@ WarpXform::GetInverseConsistencyError
       for ( int x = pVoi->From()[0]; x < pVoi->To()[0]; ++x ) 
 	{
 	v = volume->GetGridLocation( x, y, z );
-	vv = v;
-	this->ApplyInPlace( vv );
+	vv = this->Apply( v );
 	if ( inverse->InDomain( vv ) ) 
 	  {
-	  inverse->ApplyInPlace( vv );
-	  v -= vv;
+	  v -= inverse->Apply( vv );
 	  result += v.RootSumOfSquares();
 	  ++count;
 	  }
