@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3766 $
+//  $Revision: 4209 $
 //
-//  $LastChangedDate: 2012-01-31 13:52:22 -0800 (Tue, 31 Jan 2012) $
+//  $LastChangedDate: 2012-04-17 15:21:06 -0700 (Tue, 17 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -33,6 +33,7 @@
 #include "cmtkXform.h"
 
 #include <Base/cmtkVolume.h>
+#include <Base/cmtkLandmarkPairList.h>
 
 #include <math.h>
 #include <stdio.h>
@@ -99,23 +100,16 @@ Xform::GetParamVector
 }
 
 Types::Coordinate
-Xform::GetLandmarksMSD( const MatchedLandmarkList* ll ) const
+Xform::GetLandmarksMSD( const LandmarkPairList& ll ) const
 {
-  double MSD = 0;
+  Types::Coordinate msd = 0;
 
-  MatchedLandmarkList::const_iterator it = ll->begin();
-  while ( it != ll->end() )
+  for ( LandmarkPairList::const_iterator it = ll.begin(); it != ll.end(); ++it )
     {
-    Self::SpaceVectorType source( (*it)->GetLocation() );
-    Self::SpaceVectorType target( (*it)->GetTargetLocation() );
-    this->ApplyInPlace( source );
-    MSD += (source - target).SumOfSquares();
-    ++it;
+    msd += ( this->Apply( it->m_Location ) - it->m_TargetLocation ).SumOfSquares();
     }
   
-  MSD /= ll->size();
-
-  return MSD;
+  return msd / ll.size();
 }
 
 } // namespace cmtk
