@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3978 $
+//  $Revision: 4415 $
 //
-//  $LastChangedDate: 2012-03-06 15:40:08 -0800 (Tue, 06 Mar 2012) $
+//  $LastChangedDate: 2012-06-04 14:57:12 -0700 (Mon, 04 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -48,7 +48,7 @@ void
 cmtk::SimpleLevelsetDevice
 ::Evolve( const int numberOfIterations, const bool forceIterations )
 {
-  FixedVector< 3, std::vector<float> > kernels;
+  FixedArray< 3, std::vector<float> > kernels;
 
   for ( int dim = 0; dim < 3; ++dim )
     {
