@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4546 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2012-10-04 15:41:35 -0700 (Thu, 04 Oct 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -38,7 +38,8 @@
 #include <System/cmtkConsole.h>
 #include <System/cmtkStrUtility.h>
 
-#include <IO/cmtkFileConstHeader.h>
+#include <IO/cmtkSiemensCSAHeader.h>
+
 
 #ifdef CMTK_USE_DCMTK_JPEG
 #  include <dcmtk/dcmjpeg/djdecode.h>
@@ -314,7 +315,8 @@ DICOM::GetPixelDataArray( const size_t pixelDataLength )
 
 
 const FixedVector<3,double>
-DICOM::DemosaicAndGetNormal( const FixedArray< 2, FixedVector<3,double> >& imageOrientation, FixedVector<3,int>& dims, TypedArray::SmartPtr& pixelDataArray, FixedVector<3,double>& imageOrigin )
+DICOM::DemosaicAndGetNormal
+( const FixedArray< 2, FixedVector<3,double> >& imageOrientation, const FixedVector<3,Types::Coordinate>& deltas, FixedVector<3,int>& dims, TypedArray::SmartPtr& pixelDataArray, FixedVector<3,double>& imageOrigin )
 {
   // without further information, we "guess" the image normal vector
   FixedVector<3,double> sliceNormal = SurfaceNormal( imageOrientation[0], imageOrientation[1] ).Get();
@@ -330,51 +332,60 @@ DICOM::DemosaicAndGetNormal( const FixedArray< 2, FixedVector<3,double> >& image
       if ( this->Document().getValue( nSlicesTag, tempUint16 ) )
 	{
 	dims[2] = tempUint16;
-	
+	}
+
+      // check for mosaic
+      if ( dims[2] || (this->Document().getValue( DCM_ImageType, tmpStr ) && strstr( tmpStr, "MOSAIC" )) )
+	{
+	int unmosaicImageRows;
+	int unmosaicImageCols;
+
 	const DcmTagKey mosaicTag(0x0051,0x100b);
 	if ( this->Document().getValue( mosaicTag, tmpStr ) )
 	  {
-	  int rows;
-	  int cols;
-	  if ( 2 != sscanf( tmpStr, "%dp*%ds", &rows, &cols) )
+	  if ( 2 != sscanf( tmpStr, "%dp*%ds", &unmosaicImageRows, &unmosaicImageCols) )
 	    {
-	    if ( 2 != sscanf( tmpStr, "%d*%ds", &rows, &cols) )
+	    if ( 2 != sscanf( tmpStr, "%d*%ds", &unmosaicImageRows, &unmosaicImageCols) )
 	      {
-	      StdErr << "ERROR: unable to parse mosaic size from " << tmpStr << "\n";
+	      StdErr << "ERROR: unable to parse mosaic size from (0x0051,0x100b): " << tmpStr << "\n";
 	      }
 	    }
-	  
-	  if ( (cols > 0) && (rows > 0 ) )
-	    {
-	    const int xMosaic = dims[0] / cols;
-	    
-	    dims[0] = cols;
-	    dims[1] = rows;
-	    
-	    // de-mosaic the data array
-	    const unsigned long imageSizePixels = dims[0] * dims[1] * dims[2];
-	    TypedArray::SmartPtr newDataArray( TypedArray::Create( pixelDataArray->GetType(), imageSizePixels ) );
-	    
-	    const size_t pixelsPerSlice = cols * rows;
-	    size_t toOffset = 0;
-	    for ( int slice = 0; slice < dims[2]; ++slice )
-	      {
-	      for ( int j = 0; j < rows; ++j, toOffset += dims[0] )
-		{
-		const size_t iPatch = slice % xMosaic;
-		const size_t jPatch = slice / xMosaic;
-		
-		const size_t fromOffset = jPatch * xMosaic * pixelsPerSlice + j * xMosaic * cols + iPatch * cols;
-		pixelDataArray->BlockCopy( *newDataArray, toOffset, fromOffset, cols );
-		}
-	      }
-	    
-	    pixelDataArray = newDataArray;
-	    }
+	  }
 	  
 // For the following, see here: http://nipy.sourceforge.net/nibabel/dicom/siemens_csa.html#csa-header
-	  this->ParseSiemensCSA( DcmTagKey(0x0029,0x1010), sliceNormal, imageOrigin ); // image information
-	  this->ParseSiemensCSA( DcmTagKey(0x0029,0x1020), sliceNormal, imageOrigin ); // series information
+	this->ParseSiemensCSA( DcmTagKey(0x0029,0x1020), unmosaicImageCols, unmosaicImageRows, dims[2], sliceNormal, imageOrigin ); // series information
+	this->ParseSiemensCSA( DcmTagKey(0x0029,0x1010), unmosaicImageCols, unmosaicImageRows, dims[2], sliceNormal, imageOrigin ); // image information
+	
+	// hopefully we have figured out the mosaic dimensions by now.
+	if ( (unmosaicImageCols > 0) && (unmosaicImageRows > 0 ) )
+	  {
+	  const int xMosaic = dims[0] / unmosaicImageCols;
+	  
+	  dims[0] = unmosaicImageCols;
+	  dims[1] = unmosaicImageRows;
+	  
+	  // de-mosaic the data array
+	  const unsigned long imageSizePixels = dims[0] * dims[1] * dims[2];
+	  TypedArray::SmartPtr newDataArray( TypedArray::Create( pixelDataArray->GetType(), imageSizePixels ) );
+	  
+	  const size_t pixelsPerSlice = unmosaicImageCols * unmosaicImageRows;
+	  size_t toOffset = 0;
+	  for ( int slice = 0; slice < dims[2]; ++slice )
+	    {
+	    for ( int j = 0; j < unmosaicImageRows; ++j, toOffset += dims[0] )
+	      {
+	      const size_t iPatch = slice % xMosaic;
+	      const size_t jPatch = slice / xMosaic;
+	      
+	      const size_t fromOffset = jPatch * xMosaic * pixelsPerSlice + j * xMosaic * unmosaicImageCols + iPatch * unmosaicImageCols;
+	      pixelDataArray->BlockCopy( *newDataArray, toOffset, fromOffset, unmosaicImageCols );
+	      }
+	    }
+	  
+	  pixelDataArray = newDataArray;
+
+	  // convert CSA-header center-of-image origin to corner-of-image standard origin (Issue #6754)
+	  imageOrigin -= (0.5 * ((dims[0]-1) * deltas[0] * imageOrientation[0] + (dims[1]-1) * deltas[1] * imageOrientation[1]) );
 	  }
 	}
       }  
@@ -383,55 +394,63 @@ DICOM::DemosaicAndGetNormal( const FixedArray< 2, FixedVector<3,double> >& image
 }
 
 void
-DICOM::ParseSiemensCSA( const DcmTagKey& tagKey, FixedVector<3,double>& sliceNormal, FixedVector<3,double>& imageOrigin )
+DICOM::ParseSiemensCSA( const DcmTagKey& tagKey, int& unmosaicImageCols, int& unmosaicImageRows, int& slices, FixedVector<3,double>& sliceNormal, FixedVector<3,double>& imageOrigin )
 {
   const Uint8* csaHeaderInfo = NULL;
   unsigned long csaHeaderLength = 0;
   if ( this->Dataset().findAndGetUint8Array ( tagKey, csaHeaderInfo, &csaHeaderLength ).status() == OF_ok )
     {
-    FileConstHeader fileHeader( csaHeaderInfo, false /*isBigEndian*/ ); // Siemens CSA header is always little endian
-    const size_t nTags = fileHeader.GetField<Uint32>( 8 );
-    
-    size_t tagOffset = 16; // start after header
-    for ( size_t tag = 0; tag < nTags; ++tag )
-      {
-      char tagName[65];
-      fileHeader.GetFieldString( tagOffset, tagName, 64 );
-//      StdErr << tag << "\t" << tagName << "\n";
-      
-      const size_t nItems = fileHeader.GetField<Uint32>( tagOffset + 76 );
-//      StdErr << "  nItems: " << nItems << "\n";
-      
-      tagOffset += 84;
-      for ( size_t item = 0; item < nItems; ++item )
-	{
-	const size_t itemLen = fileHeader.GetField<Uint32>( tagOffset );
-	
-//	StdErr << "    len: " << itemLen << "\n";
-	
-	if ( ! strcmp( tagName, "SliceNormalVector" ) && (item < 3) )
-	  {
-	  char valStr[65];
-	  sliceNormal[item] = atof( fileHeader.GetFieldString( tagOffset+16, valStr, 64 ) );
-	  
-//	  StdErr << "    " << valStr << "\n";
-	  }
+    SiemensCSAHeader csaHeader( (const char*)csaHeaderInfo, csaHeaderLength );
 
-	// get true slice0 location from CSA header
-	if ( ! strcmp( tagName, "MrPhoenixProtocol" ) )
+    SiemensCSAHeader::const_iterator it = csaHeader.find( "AcquisitionMatrixText" );
+    if ( (it != csaHeader.end()) && !it->second.empty() )
+      {
+      if ( 2 != sscanf( it->second[0].c_str(), "%dp*%ds", &unmosaicImageRows, &unmosaicImageCols) )
+	{
+	if ( 2 != sscanf( it->second[0].c_str(), "%d*%ds", &unmosaicImageRows, &unmosaicImageCols) )
 	  {
-	  const char* pSliceZero = StrNStr( reinterpret_cast<const char*>( csaHeaderInfo+tagOffset+16 ), itemLen, "sSliceArray.asSlice[0].sPosition.dSag" );
-	  if ( pSliceZero )
+	  StdErr << "ERROR: unable to parse mosaic size from CSA field AcquisitionMatrixText: " << it->second[0] << "\n";
+	  }
+	}
+      }
+
+    it = csaHeader.find( "NumberOfImagesInMosaic" );
+    if ( (it != csaHeader.end()) && !it->second.empty() )
+      slices = atof( it->second[0].c_str() );
+
+    it = csaHeader.find( "SliceNormalVector" );
+    if ( (it != csaHeader.end()) && (it->second.size() >= 3) )
+      {
+      for ( size_t i = 0; i < 3; ++i )
+	sliceNormal[i] = atof( it->second[i].c_str() );
+      }
+
+    // get true slice0 location from CSA header
+    it = csaHeader.find( "MrPhoenixProtocol" );
+    if ( (it != csaHeader.end()) && !it->second.empty() )
+      {
+      // ID strings for three axes in CSA header
+      const std::string sliceOrientationString[] = { "dSag", "dCor", "dTra" };
+      
+      for ( int i = 0; i < 3; ++i )
+	{
+	const size_t sliceTagPos = it->second[0].find( std::string( "sSliceArray.asSlice[0].sPosition." ) + sliceOrientationString[i] );
+	  if ( sliceTagPos != std::string::npos )
 	    {
-	    for ( int i = 0; i < 3; ++i )
+	    const size_t equalPos = it->second[0].find( '=', sliceTagPos );
+	    if ( equalPos != std::string::npos )
 	      {
-	      while ( *pSliceZero != '=' ) ++pSliceZero;
-	      imageOrigin[i] = atof( ++pSliceZero );
+	      imageOrigin[i] = atof( it->second[0].substr( equalPos + 1 ).c_str() );
+	      }
+	    else
+	      {
+	      StdErr << "ERROR: unable to get image origin component from: " << it->second[0] << "\n";
 	      }
 	    }
-	  }
-	
-	tagOffset += 4*((itemLen+3)/4) /*move up to nearest 4-byte boundary*/ + 16 /*the 4 ints at the beginning of item, including itemLength*/;
+	  else
+	    {
+	    StdErr << "ERROR: unable to get image origin tag for component " <<  sliceOrientationString[i] << " from CSA header\n";
+	    }
 	}
       }
     }
