@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4415 $
+//  $Revision: 4527 $
 //
-//  $LastChangedDate: 2012-06-04 14:57:12 -0700 (Mon, 04 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 10:16:03 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -88,6 +88,7 @@ public:
 
   /// Demosaic (if necessary) the image and return slice normal vector.
   const FixedVector<3,double> DemosaicAndGetNormal( const FixedArray< 2, FixedVector<3,double> >& imageOrientation /*!< Image orientation vectors (read-only, for default normal computation)*/, 
+						    const FixedVector<3,Types::Coordinate>& deltas /*!< Pixel size - this is needed for computing image origin coordinates from image center location */,
 						    FixedVector<3,int>& dims /*!< Image dimensions - these may be modified if the image is a mosaic */, 
 						    TypedArray::SmartPtr& pixelDataArray /*!< Pixel data array - a new array will be returned if the image is a mosaic.*/,
 						    FixedVector<3,double>& imageOrigin /*!< True image origin from CSA header if this is a mosaic file. */);
@@ -128,7 +129,12 @@ private:
   std::auto_ptr<DiDocument> m_Document;
 
   /// Parse private Siemens CSA data.
-  void ParseSiemensCSA( const DcmTagKey& tagKey, FixedVector<3,double>& sliceNormal, FixedVector<3,double>& imageOrigin );
+  void ParseSiemensCSA( const DcmTagKey& tagKey /*!< DCM tag with the Siemens CSA header data */, 
+			int& unmosaicImageCols /*!< Return demosaiced image columns */, 
+			int& unmosaicImageRows /*!< Return demosaiced image rows */, 
+			int& slices /*!< Return demosaiced image slices */, 
+			FixedVector<3,double>& sliceNormal /*!< Return demosaiced image slice normal */,
+			FixedVector<3,double>& imageOrigin /*!< Return demosaiced image origin */ );
 };
 
 //@}
