@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 4504 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2012-09-07 11:35:09 -0700 (Fri, 07 Sep 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -83,10 +83,6 @@ const UniformVolume::SmartPtr
 VolumeFromStudy::AssembleVolume( const StudyImageSet* study )
 {
   UniformVolume::SmartPtr Result( NULL );
-  
-  if ( study->size() < 2 ) 
-    return Result;
-  
   const std::string imageDir = MountPoints::Translate( study->GetImageDirectory() );
 
   try
