@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3378 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2011-08-18 13:55:21 -0700 (Thu, 18 Aug 2011) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -388,11 +388,11 @@ VolumeInjectionReconstruction
 	  UniformVolume::CoordinateVectorType v = passImage->GetGridLocation( x, y, z );
 	  if ( passImageXformInverse )
 	    {
-	    passImageXformInverse->ApplyInPlace( v );
+	    v = passImageXformInverse->Apply( v );
 	    }
 	  else
 	    {
-	    this->m_TransformationsToPassImages[pass]->ApplyInverseInPlace( v );
+	    this->m_TransformationsToPassImages[pass]->ApplyInverse( v, v );
 	    }
 	  
 	  int targetGridPosition[3];
