@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3700 $
+//  $Revision: 4398 $
 //
-//  $LastChangedDate: 2012-01-06 16:28:06 -0800 (Fri, 06 Jan 2012) $
+//  $LastChangedDate: 2012-05-31 11:48:23 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -47,7 +47,8 @@
 #include <Base/cmtkTransformChangeFromSpaceAffine.h>
 
 #include <IO/cmtkVolumeIO.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkClassStreamAffineXform.h>
 #include <IO/cmtkXformIO.h>
 #include <IO/cmtkAffineXformITKIO.h>
@@ -220,7 +221,7 @@ AffineRegistrationCommandLine
     
     DebugOutput( 1 ) << "Reading input studylist " << this->m_InitialXformPath << ".\n";
     
-    ClassStream typedStream( MountPoints::Translate(this->m_InitialXformPath), "registration", ClassStream::MODE_READ );
+    ClassStreamInput typedStream( MountPoints::Translate(this->m_InitialXformPath), "registration" );
     if ( ! typedStream.IsValid() ) 
       {
       StdErr << "ERROR: could not open studylist archive " << this->m_InitialXformPath << ".\n";
@@ -342,15 +343,14 @@ AffineRegistrationCommandLine::InitRegistration ()
 void
 AffineRegistrationCommandLine::OutputResultMatrix( const char* matrixName ) const
 {
-  Types::Coordinate matrix[4][4];
-  this->GetTransformation()->GetMatrix( matrix );
-
+  const AffineXform::MatrixType& matrix = this->GetTransformation()->Matrix;
+  
   FILE* mfile = fopen( matrixName, "w" );
   if ( mfile )
     {
     for ( int i = 0; i < 4; ++i )
       {
-      fprintf( mfile, "%e\t%e\t%e\t%e\n", matrix[0][i], matrix[1][i], matrix[2][i], matrix[3][i] );
+      fprintf( mfile, "%e\t%e\t%e\t%e\n", static_cast<float>( matrix[0][i] ), static_cast<float>( matrix[1][i] ), static_cast<float>( matrix[2][i] ), static_cast<float>( matrix[3][i] ) );
       }
     fclose( mfile );
     }
@@ -372,7 +372,7 @@ AffineRegistrationCommandLine::OutputResultParameters
 void
 AffineRegistrationCommandLine::OutputResultList( const char* studyList ) const
 {
-  ClassStream classStream( studyList, "studylist", ClassStream::MODE_WRITE );
+  ClassStreamOutput classStream( studyList, "studylist", ClassStreamOutput::MODE_WRITE );
   if ( !classStream.IsValid() ) return;
   
   classStream.Begin( "studylist" );
@@ -389,7 +389,7 @@ AffineRegistrationCommandLine::OutputResultList( const char* studyList ) const
     
   classStream.Close();
     
-  classStream.Open( studyList, "registration", ClassStream::MODE_WRITE );
+  classStream.Open( studyList, "registration", ClassStreamOutput::MODE_WRITE );
     
   classStream.Begin( "registration" );
   classStream.WriteString( "reference_study", CompressedStream::GetBaseName( Study1 ) );
@@ -400,7 +400,7 @@ AffineRegistrationCommandLine::OutputResultList( const char* studyList ) const
   classStream.End();
   classStream.Close();
     
-  classStream.Open( studyList, "settings", ClassStream::MODE_WRITE );
+  classStream.Open( studyList, "settings", ClassStreamOutput::MODE_WRITE );
   classStream.WriteDouble( "exploration", this->m_Exploration );
   classStream.WriteDouble( "accuracy", this->m_Accuracy );
   classStream.WriteDouble( "min_sampling", this->m_Sampling );
@@ -414,7 +414,7 @@ AffineRegistrationCommandLine::OutputResultList( const char* studyList ) const
 
   classStream.Close();
     
-  classStream.Open( studyList, "statistics", ClassStream::MODE_WRITE );
+  classStream.Open( studyList, "statistics", ClassStreamOutput::MODE_WRITE );
   classStream.WriteDouble( "time", this->GetTotalElapsedTime() );
   classStream.WriteDouble( "walltime", this->GetTotalElapsedWalltime() );
 #ifdef CMTK_USE_PTHREADS
