@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3608 $
+//  $Revision: 4510 $
 //
-//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
+//  $LastChangedDate: 2012-09-14 14:34:59 -0700 (Fri, 14 Sep 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -33,6 +33,8 @@
 #include <Registration/cmtkGroupwiseRegistrationRMIFunctional.h>
 
 #include <Base/cmtkMathUtil.h>
+#include <Base/cmtkEigenValuesSymmetricMatrix.h>
+
 #include <System/cmtkThreadPool.h>
 
 #include <algorithm>
@@ -76,7 +78,7 @@ GroupwiseRegistrationRMIFunctional<TXform>
   ThreadPool& threadPool = ThreadPool::GetGlobalThreadPool();
   const size_t numberOfImages = this->m_ImageVector.size();
 
-  this->m_CovarianceMatrix.Resize( numberOfImages, numberOfImages ); // needs no reset
+  this->m_CovarianceMatrix.Resize( numberOfImages ); // needs no reset
   this->m_TotalNumberOfSamples = 0;
 
   this->m_SumOfProductsMatrix.resize( numberOfImages * (1+numberOfImages) / 2 );
@@ -120,13 +122,12 @@ GroupwiseRegistrationRMIFunctional<TXform>
     {
     for ( size_t i = 0; i <= j; ++i, ++midx )
       {
-      covarianceMatrix[i][j] = covarianceMatrix[j][i] = (sumOfProductsMatrix[midx] - ((1.0 * sumsVector[i] * sumsVector[j]) / totalNumberOfSamples)) / totalNumberOfSamples;
+      covarianceMatrix(i,j) = (sumOfProductsMatrix[midx] - ((1.0 * sumsVector[i] * sumsVector[j]) / totalNumberOfSamples)) / totalNumberOfSamples;
       }
     }
   
-  std::vector<typename Self::ReturnType> eigenvalues( numberOfImages );
-  MathUtil::ComputeEigenvalues<typename Self::ReturnType>( covarianceMatrix, eigenvalues );
-
+  const std::vector<typename Self::ReturnType> eigenvalues = EigenValuesSymmetricMatrix<typename Self::ReturnType>( covarianceMatrix ).GetEigenvalues();
+  
   const typename Self::ReturnType EIGENVALUE_THRESHOLD = 1e-6;
   typename Self::ReturnType determinant = 1.0;
   for ( size_t i = 0; i < numberOfImages; ++i )
