@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3608 $
+//  $Revision: 4510 $
 //
-//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
+//  $LastChangedDate: 2012-09-14 14:34:59 -0700 (Fri, 14 Sep 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -44,7 +44,7 @@
 #include <Base/cmtkUniformVolume.h>
 #include <Base/cmtkXform.h>
 #include <Base/cmtkMathUtil.h>
-#include <Base/cmtkMatrix.h>
+#include <Base/cmtkSymmetricMatrix.h>
 
 #include <vector>
 
@@ -102,7 +102,7 @@ public:
   
 protected:
   /// Covariance matrix type.
-  typedef Matrix2D<typename Self::ReturnType> CovarianceMatrixType;
+  typedef SymmetricMatrix<typename Self::ReturnType> CovarianceMatrixType;
 
   /// Actual covariance matrix.
   typename Self::CovarianceMatrixType m_CovarianceMatrix;
