@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3722 $
+//  $Revision: 4398 $
 //
-//  $LastChangedDate: 2012-01-11 13:38:56 -0800 (Wed, 11 Jan 2012) $
+//  $LastChangedDate: 2012-05-31 11:48:23 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -51,7 +51,8 @@
 #include <Registration/cmtkMakeInitialAffineTransformation.h>
 
 #include <IO/cmtkVolumeIO.h>
-#include <IO/cmtkClassStream.h>
+#include <IO/cmtkClassStreamInput.h>
+#include <IO/cmtkClassStreamOutput.h>
 #include <IO/cmtkClassStreamAffineXform.h>
 #include <IO/cmtkXformIO.h>
 #include <IO/cmtkAffineXformITKIO.h>
@@ -249,7 +250,7 @@ ImagePairAffineRegistrationCommandLine
     
     DebugOutput( 1 ) << "Reading input studylist " << inStudylist << ".\n";
     
-    ClassStream typedStream( MountPoints::Translate(inStudylist), "registration", ClassStream::MODE_READ );
+    ClassStreamInput typedStream( MountPoints::Translate(inStudylist), "registration" );
     if ( ! typedStream.IsValid() ) 
       {
       StdErr << "ERROR: could not open studylist archive " << inStudylist << ".\n";
@@ -361,15 +362,14 @@ ImagePairAffineRegistrationCommandLine::InitRegistration ()
 void
 ImagePairAffineRegistrationCommandLine::OutputResultMatrix( const char* matrixName ) const
 {
-  Types::Coordinate matrix[4][4];
-  this->GetTransformation()->GetMatrix( matrix );
-
+  const AffineXform::MatrixType& matrix = this->GetTransformation()->Matrix;
+  
   FILE* mfile = fopen( matrixName, "w" );
   if ( mfile )
     {
     for ( int i = 0; i < 4; ++i )
       {
-      fprintf( mfile, "%e\t%e\t%e\t%e\n", matrix[0][i], matrix[1][i], matrix[2][i], matrix[3][i] );
+      fprintf( mfile, "%e\t%e\t%e\t%e\n", static_cast<float>( matrix[0][i] ), static_cast<float>( matrix[1][i] ), static_cast<float>( matrix[2][i] ), static_cast<float>( matrix[3][i] ) );
       }
     fclose( mfile );
     }
@@ -391,7 +391,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultParameters
 void
 ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList ) const
 {
-  ClassStream classStream( studyList, "studylist", ClassStream::MODE_WRITE );
+  ClassStreamOutput classStream( studyList, "studylist", ClassStreamOutput::MODE_WRITE );
   if ( !classStream.IsValid() ) return;
   
   classStream.Begin( "studylist" );
@@ -408,7 +408,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList
     
   classStream.Close();
     
-  classStream.Open( studyList, "registration", ClassStream::MODE_WRITE );
+  classStream.Open( studyList, "registration", ClassStreamOutput::MODE_WRITE );
     
   classStream.Begin( "registration" );
   classStream.WriteString( "reference_study", CompressedStream::GetBaseName( Study1 ) );
@@ -419,7 +419,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList
   classStream.End();
   classStream.Close();
     
-  classStream.Open( studyList, "settings", ClassStream::MODE_WRITE );
+  classStream.Open( studyList, "settings", ClassStreamOutput::MODE_WRITE );
   classStream.WriteDouble( "exploration", this->m_MaxStepSize );
   classStream.WriteDouble( "accuracy", this->m_MinStepSize );
   classStream.WriteDouble( "min_sampling", this->m_Sampling );
@@ -433,7 +433,7 @@ ImagePairAffineRegistrationCommandLine::OutputResultList( const char* studyList
 
   classStream.Close();
     
-  classStream.Open( studyList, "statistics", ClassStream::MODE_WRITE );
+  classStream.Open( studyList, "statistics", ClassStreamOutput::MODE_WRITE );
   classStream.WriteDouble( "time", this->GetTotalElapsedTime() );
   classStream.WriteDouble( "walltime", this->GetTotalElapsedWalltime() );
 #ifdef CMTK_USE_PTHREADS
