@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4426 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-06-12 10:30:56 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -448,8 +448,7 @@ cmtk::ImageSymmetryPlaneCommandLineBase
       {
       for ( int x = 0; x < originalVolume->GetDims()[0]; ++x, ++offset ) 
 	{
-	UniformVolume::CoordinateVectorType v = originalVolume->GetGridLocation( x, y, z );
-	alignment->ApplyInPlace( v );
+	const UniformVolume::CoordinateVectorType v = alignment->Apply( originalVolume->GetGridLocation( x, y, z ) );
 
 	if ( interpolator->GetDataAt( v, data ) )
 	  {
