@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3608 $
+//  $Revision: 4344 $
 //
-//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
+//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -46,8 +46,6 @@
 #include <Base/cmtkSplineWarpXform.h>
 #include <Base/cmtkHistogram.h>
 
-#include <IO/cmtkClassStream.h>
-
 #include <vector>
 
 namespace
