@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4306 $
+//  $Revision: 4389 $
 //
-//  $LastChangedDate: 2012-05-04 10:06:54 -0700 (Fri, 04 May 2012) $
+//  $LastChangedDate: 2012-05-31 08:52:39 -0700 (Thu, 31 May 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -63,14 +63,14 @@ CompressedStream::ArchiveLookup[] = {
   {".gz",   "gzip -cd %s > %s"},
   {".bz",   "bzip -Q -cd %s > %s"},
   {".bz2",  "bzip2 -cd %s > %s"},
-  {".lzma", "lzma -cd %s > %s"},
+  {".lzma", "xz -cd %s > %s"},
   {".xz",   "xz -cd %s > %s"},
 #else
   {".Z",    "gunzip -c %s"},
   {".gz",   "gzip -cd %s"},
   {".bz",   "bzip -Q -cd %s"},
   {".bz2",  "bzip2 -cd %s"},
-  {".lzma", "lzma -cd %s"},
+  {".lzma", "xz -cd %s"},
   {".xz",   "xz -cd %s"},
 #endif
   { NULL,   NULL} 
