@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3812 $
+//  $Revision: 4260 $
 //
-//  $LastChangedDate: 2012-02-02 15:52:58 -0800 (Thu, 02 Feb 2012) $
+//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -41,9 +41,9 @@ namespace
 cmtk
 {
 
-CompressedStream::BZip2::BZip2( const char* filename ) 
+CompressedStream::BZip2::BZip2( const std::string& filename ) 
 {
-  this->m_BzFile = BZ2_bzopen( filename, CMTK_FILE_MODE );
+  this->m_BzFile = BZ2_bzopen( filename.c_str(), CMTK_FILE_MODE );
   if ( !this->m_BzFile ) 
     {
     StdErr << "ERROR: CompressedStream::BZip2 could not open file '" << filename << "'\n";
