@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2012 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3608 $
+//  $Revision: 4541 $
 //
-//  $LastChangedDate: 2011-12-02 10:47:18 -0800 (Fri, 02 Dec 2011) $
+//  $LastChangedDate: 2012-10-04 12:56:38 -0700 (Thu, 04 Oct 2012) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -39,6 +39,7 @@
 
 #include <iostream>
 #include <string>
+#include <cassert>
 
 #include <System/cmtkMutexLock.h>
 #include <System/cmtkLockingPtr.h>
@@ -107,6 +108,13 @@ public:
   /// Decrement indentation level.
   void unindent() { IndentLevel -= 2; }
 
+  /// Implicit conversion to C++ ostream.
+  operator std::ostream&()
+  {
+    assert( this->m_StreamP ); // will fail for StdNull!
+    return *(this->m_StreamP);
+  }
+
 private:
   /// The system stream that we're attaching to.
   std::ostream* m_StreamP;
